@@ -122,11 +122,11 @@ def parse_price(p: Product, html: str = None, selector: parsel.Selector = None):
         if numpy.all(t["price"] == ""):
             return ""
         if numpy.any(t["price"] == ""):
-            return t["price"][t["price"] != ""][0]
+            return str(t["price"][t["price"] != ""][0])
         if t.at["discount", "title"] == "Deal of the Day:":
-            return t.at["origin", "price"]
+            return str(t.at["origin", "price"])
         else:
-            return t.at["discount", "price"]
+            return str(t.at["discount", "price"])
 
     prices_str = s1() or s2()
     prices: Union[None, list] = parse_number(prices_str.replace(",", ""), first=False)
